#!/bin/bash
#
# source: http://files.libburnia-project.org/releases/libburn-0.7.6.pl00.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft="libburn"
softversion="0.7.6.pl00"
arch="i486"
cpu="i686"
packageversion="64.1"


buildir=$(pwd)
srcpkg="$buildir/$soft-0.7.6.pl00.tar.gz"
src="$buildir/$soft-0.7.6"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
   --prefix=/usr \
   --sysconfdir=/etc \
   --mandir=/usr/man \
   --disable-static

make
make install DESTDIR=$dest


find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

gzip -9 $dest/usr/man/*/*

#-------------------Prepare the documentation:

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog CONTRIBUTORS COPYING COPYRIGHT INSTALL NEWS README $dest/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

       |-----handy-ruler------------------------------------------------------|
libburn: libburn - is the foundation of our cdrecord emulation
libburn:
libburn: is the library by which preformatted data get onto optical media.
libburn: It uses either /dev/sgN (e.g. on kernel 2.4 with ide-scsi) or
libburn: /dev/srM or /dev/hdX (e.g. on kernel 2.6).
libburn:
libburn: cdrskin ( is a limited cdrecord compatibility wrapper for libburn )
libburn: is a limited cdrecord compatibility wrapper for libburn.
libburn: cdrecord is a powerful GPL'ed burn program included in Joerg
libburn: Schilling's cdrtools.
libburn:
EODESC

#-------------------copy the build-script in /usr/src

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5